==> pmml-model-1.5.1-sources.jar: org/dmg/pmml/time_series/PMMLAttributes.java <==

package org.dmg.pmml.time_series;

import java.lang.reflect.Field;

public interface PMMLAttributes {

    Field ARIMA_RMSE = org.jpmml.model.ReflectionUtil.getField(ARIMA.class, "rmse");
    Field ARIMA_TRANSFORMATION = org.jpmml.model.ReflectionUtil.getField(ARIMA.class, "transformation");
    Field ARIMA_CONSTANTTERM = org.jpmml.model.ReflectionUtil.getField(ARIMA.class, "constantTerm");
    Field ARIMA_PREDICTIONMETHOD = org.jpmml.model.ReflectionUtil.getField(ARIMA.class, "predictionMethod");
    Field ARMAPART_CONSTANT = org.jpmml.model.ReflectionUtil.getField(ARMAPart.class, "constant");
    Field ARMAPART_P = org.jpmml.model.ReflectionUtil.getField(ARMAPart.class, "p");
    Field ARMAPART_Q = org.jpmml.model.ReflectionUtil.getField(ARMAPart.class, "q");
    Field DYNAMICREGRESSOR_FIELD = org.jpmml.model.ReflectionUtil.getField(DynamicRegressor.class, "field");
    Field DYNAMICREGRESSOR_TRANSFORMATION = org.jpmml.model.ReflectionUtil.getField(DynamicRegressor.class, "transformation");
    Field DYNAMICREGRESSOR_DELAY = org.jpmml.model.ReflectionUtil.getField(DynamicRegressor.class, "delay");
    Field DYNAMICREGRESSOR_FUTUREVALUESMETHOD = org.jpmml.model.ReflectionUtil.getField(DynamicRegressor.class, "futureValuesMethod");
    Field DYNAMICREGRESSOR_TARGETFIELD = org.jpmml.model.ReflectionUtil.getField(DynamicRegressor.class, "targetField");
    Field EXPONENTIALSMOOTHING_RMSE = org.jpmml.model.ReflectionUtil.getField(ExponentialSmoothing.class, "rmse");
    Field EXPONENTIALSMOOTHING_TRANSFORMATION = org.jpmml.model.ReflectionUtil.getField(ExponentialSmoothing.class, "transformation");
    Field GARCHPART_CONSTANT = org.jpmml.model.ReflectionUtil.getField(GARCHPart.class, "constant");
    Field GARCHPART_GP = org.jpmml.model.ReflectionUtil.getField(GARCHPart.class, "gp");
    Field GARCHPART_GQ = org.jpmml.model.ReflectionUtil.getField(GARCHPart.class, "gq");
    Field LEVEL_ALPHA = org.jpmml.model.ReflectionUtil.getField(Level.class, "alpha");
    Field LEVEL_QUADRATICSMOOTHEDVALUE = org.jpmml.model.ReflectionUtil.getField(Level.class, "quadraticSmoothedValue");
    Field LEVEL_CUBICSMOOTHEDVALUE = org.jpmml.model.ReflectionUtil.getField(Level.class, "cubicSmoothedValue");
    Field LEVEL_SMOOTHEDVALUE = org.jpmml.model.ReflectionUtil.getField(Level.class, "smoothedValue");
    Field MAXIMUMLIKELIHOODSTAT_METHOD = org.jpmml.model.ReflectionUtil.getField(MaximumLikelihoodStat.class, "method");
    Field MAXIMUMLIKELIHOODSTAT_PERIODDEFICIT = org.jpmml.model.ReflectionUtil.getField(MaximumLikelihoodStat.class, "periodDeficit");
    Field NONSEASONALCOMPONENT_P = org.jpmml.model.ReflectionUtil.getField(NonseasonalComponent.class, "p");
    Field NONSEASONALCOMPONENT_D = org.jpmml.model.ReflectionUtil.getField(NonseasonalComponent.class, "d");
    Field NONSEASONALCOMPONENT_Q = org.jpmml.model.ReflectionUtil.getField(NonseasonalComponent.class, "q");
    Field NONSEASONALFACTOR_DIFFERENCE = org.jpmml.model.ReflectionUtil.getField(NonseasonalFactor.class, "difference");
    Field NONSEASONALFACTOR_MAXIMUMORDER = org.jpmml.model.ReflectionUtil.getField(NonseasonalFactor.class, "maximumOrder");
    Field OUTLIEREFFECT_TYPE = org.jpmml.model.ReflectionUtil.getField(OutlierEffect.class, "type");
    Field OUTLIEREFFECT_STARTTIME = org.jpmml.model.ReflectionUtil.getField(OutlierEffect.class, "startTime");
    Field OUTLIEREFFECT_MAGNITUDE = org.jpmml.model.ReflectionUtil.getField(OutlierEffect.class, "magnitude");
    Field OUTLIEREFFECT_DAMPINGCOEFFICIENT = org.jpmml.model.ReflectionUtil.getField(OutlierEffect.class, "dampingCoefficient");
    Field PSIVECTOR_TARGETFIELD = org.jpmml.model.ReflectionUtil.getField(PsiVector.class, "targetField");
    Field PSIVECTOR_VARIANCE = org.jpmml.model.ReflectionUtil.getField(PsiVector.class, "variance");
    Field SEASONALCOMPONENT_P = org.jpmml.model.ReflectionUtil.getField(SeasonalComponent.class, "p");
    Field SEASONALCOMPONENT_D = org.jpmml.model.ReflectionUtil.getField(SeasonalComponent.class, "d");
    Field SEASONALCOMPONENT_Q = org.jpmml.model.ReflectionUtil.getField(SeasonalComponent.class, "q");
    Field SEASONALCOMPONENT_PERIOD = org.jpmml.model.ReflectionUtil.getField(SeasonalComponent.class, "period");
    Field SEASONALFACTOR_DIFFERENCE = org.jpmml.model.ReflectionUtil.getField(SeasonalFactor.class, "difference");
    Field SEASONALFACTOR_MAXIMUMORDER = org.jpmml.model.ReflectionUtil.getField(SeasonalFactor.class, "maximumOrder");
    Field SEASONALITYEXPOSMOOTH_TYPE = org.jpmml.model.ReflectionUtil.getField(SeasonalityExpoSmooth.class, "type");
    Field SEASONALITYEXPOSMOOTH_PERIOD = org.jpmml.model.ReflectionUtil.getField(SeasonalityExpoSmooth.class, "period");
    Field SEASONALITYEXPOSMOOTH_UNIT = org.jpmml.model.ReflectionUtil.getField(SeasonalityExpoSmooth.class, "unit");
    Field SEASONALITYEXPOSMOOTH_PHASE = org.jpmml.model.ReflectionUtil.getField(SeasonalityExpoSmooth.class, "phase");
    Field SEASONALITYEXPOSMOOTH_DELTA = org.jpmml.model.ReflectionUtil.getField(SeasonalityExpoSmooth.class, "delta");
    Field STATESPACEMODEL_VARIANCE = org.jpmml.model.ReflectionUtil.getField(StateSpaceModel.class, "variance");
    Field STATESPACEMODEL_PERIOD = org.jpmml.model.ReflectionUtil.getField(StateSpaceModel.class, "period");
    Field STATESPACEMODEL_INTERCEPT = org.jpmml.model.ReflectionUtil.getField(StateSpaceModel.class, "intercept");
    Field THETA_I = org.jpmml.model.ReflectionUtil.getField(Theta.class, "i");
    Field THETA_J = org.jpmml.model.ReflectionUtil.getField(Theta.class, "j");
    Field THETA_THETA = org.jpmml.model.ReflectionUtil.getField(Theta.class, "theta");
    Field TIMEANCHOR_TYPE = org.jpmml.model.ReflectionUtil.getField(TimeAnchor.class, "type");
    Field TIMEANCHOR_OFFSET = org.jpmml.model.ReflectionUtil.getField(TimeAnchor.class, "offset");
    Field TIMEANCHOR_STEPSIZE = org.jpmml.model.ReflectionUtil.getField(TimeAnchor.class, "stepsize");
    Field TIMEANCHOR_DISPLAYNAME = org.jpmml.model.ReflectionUtil.getField(TimeAnchor.class, "displayName");
    Field TIMECYCLE_LENGTH = org.jpmml.model.ReflectionUtil.getField(TimeCycle.class, "length");
    Field TIMECYCLE_TYPE = org.jpmml.model.ReflectionUtil.getField(TimeCycle.class, "type");
    Field TIMECYCLE_DISPLAYNAME = org.jpmml.model.ReflectionUtil.getField(TimeCycle.class, "displayName");
    Field TIMEEXCEPTION_TYPE = org.jpmml.model.ReflectionUtil.getField(TimeException.class, "type");
    Field TIMEEXCEPTION_COUNT = org.jpmml.model.ReflectionUtil.getField(TimeException.class, "count");
    Field TIMESERIES_USAGE = org.jpmml.model.ReflectionUtil.getField(TimeSeries.class, "usage");
    Field TIMESERIES_STARTTIME = org.jpmml.model.ReflectionUtil.getField(TimeSeries.class, "startTime");
    Field TIMESERIES_ENDTIME = org.jpmml.model.ReflectionUtil.getField(TimeSeries.class, "endTime");
    Field TIMESERIES_INTERPOLATIONMETHOD = org.jpmml.model.ReflectionUtil.getField(TimeSeries.class, "interpolationMethod");
    Field TIMESERIES_FIELD = org.jpmml.model.ReflectionUtil.getField(TimeSeries.class, "field");
    Field TIMESERIESMODEL_MODELNAME = org.jpmml.model.ReflectionUtil.getField(TimeSeriesModel.class, "modelName");
    Field TIMESERIESMODEL_MININGFUNCTION = org.jpmml.model.ReflectionUtil.getField(TimeSeriesModel.class, "miningFunction");
    Field TIMESERIESMODEL_ALGORITHMNAME = org.jpmml.model.ReflectionUtil.getField(TimeSeriesModel.class, "algorithmName");
    Field TIMESERIESMODEL_BESTFIT = org.jpmml.model.ReflectionUtil.getField(TimeSeriesModel.class, "bestFit");
    Field TIMESERIESMODEL_SCORABLE = org.jpmml.model.ReflectionUtil.getField(TimeSeriesModel.class, "scorable");
    Field TIMESERIESMODEL_MATHCONTEXT = org.jpmml.model.ReflectionUtil.getField(TimeSeriesModel.class, "mathContext");
    Field TIMEVALUE_INDEX = org.jpmml.model.ReflectionUtil.getField(TimeValue.class, "index");
    Field TIMEVALUE_TIME = org.jpmml.model.ReflectionUtil.getField(TimeValue.class, "time");
    Field TIMEVALUE_VALUE = org.jpmml.model.ReflectionUtil.getField(TimeValue.class, "value");
    Field TIMEVALUE_STANDARDERROR = org.jpmml.model.ReflectionUtil.getField(TimeValue.class, "standardError");
    Field TRENDEXPOSMOOTH_TREND = org.jpmml.model.ReflectionUtil.getField(TrendExpoSmooth.class, "trend");
    Field TRENDEXPOSMOOTH_GAMMA = org.jpmml.model.ReflectionUtil.getField(TrendExpoSmooth.class, "gamma");
    Field TRENDEXPOSMOOTH_PHI = org.jpmml.model.ReflectionUtil.getField(TrendExpoSmooth.class, "phi");
    Field TRENDEXPOSMOOTH_SMOOTHEDVALUE = org.jpmml.model.ReflectionUtil.getField(TrendExpoSmooth.class, "smoothedValue");

}

==> pmml-model-1.5.7-sources.jar: org/dmg/pmml/time_series/PMMLAttributes.java <==

package org.dmg.pmml.time_series;

import java.lang.reflect.Field;

public interface PMMLAttributes {

    Field ARIMA_RMSE = org.jpmml.model.ReflectionUtil.getField(ARIMA.class, "rmse");
    Field ARIMA_TRANSFORMATION = org.jpmml.model.ReflectionUtil.getField(ARIMA.class, "transformation");
    Field ARIMA_CONSTANTTERM = org.jpmml.model.ReflectionUtil.getField(ARIMA.class, "constantTerm");
    Field ARIMA_PREDICTIONMETHOD = org.jpmml.model.ReflectionUtil.getField(ARIMA.class, "predictionMethod");
    Field ARMAPART_CONSTANT = org.jpmml.model.ReflectionUtil.getField(ARMAPart.class, "constant");
    Field ARMAPART_P = org.jpmml.model.ReflectionUtil.getField(ARMAPart.class, "p");
    Field ARMAPART_Q = org.jpmml.model.ReflectionUtil.getField(ARMAPart.class, "q");
    Field DYNAMICREGRESSOR_FIELD = org.jpmml.model.ReflectionUtil.getField(DynamicRegressor.class, "field");
    Field DYNAMICREGRESSOR_TRANSFORMATION = org.jpmml.model.ReflectionUtil.getField(DynamicRegressor.class, "transformation");
    Field DYNAMICREGRESSOR_DELAY = org.jpmml.model.ReflectionUtil.getField(DynamicRegressor.class, "delay");
    Field DYNAMICREGRESSOR_FUTUREVALUESMETHOD = org.jpmml.model.ReflectionUtil.getField(DynamicRegressor.class, "futureValuesMethod");
    Field DYNAMICREGRESSOR_TARGETFIELD = org.jpmml.model.ReflectionUtil.getField(DynamicRegressor.class, "targetField");
    Field EXPONENTIALSMOOTHING_RMSE = org.jpmml.model.ReflectionUtil.getField(ExponentialSmoothing.class, "rmse");
    Field EXPONENTIALSMOOTHING_TRANSFORMATION = org.jpmml.model.ReflectionUtil.getField(ExponentialSmoothing.class, "transformation");
    Field GARCHPART_CONSTANT = org.jpmml.model.ReflectionUtil.getField(GARCHPart.class, "constant");
    Field GARCHPART_GP = org.jpmml.model.ReflectionUtil.getField(GARCHPart.class, "gp");
    Field GARCHPART_GQ = org.jpmml.model.ReflectionUtil.getField(GARCHPart.class, "gq");
    Field INTERCEPTVECTOR_TYPE = org.jpmml.model.ReflectionUtil.getField(InterceptVector.class, "type");
    Field LEVEL_ALPHA = org.jpmml.model.ReflectionUtil.getField(Level.class, "alpha");
    Field LEVEL_QUADRATICSMOOTHEDVALUE = org.jpmml.model.ReflectionUtil.getField(Level.class, "quadraticSmoothedValue");
    Field LEVEL_CUBICSMOOTHEDVALUE = org.jpmml.model.ReflectionUtil.getField(Level.class, "cubicSmoothedValue");
    Field LEVEL_SMOOTHEDVALUE = org.jpmml.model.ReflectionUtil.getField(Level.class, "smoothedValue");
    Field MAXIMUMLIKELIHOODSTAT_METHOD = org.jpmml.model.ReflectionUtil.getField(MaximumLikelihoodStat.class, "method");
    Field MAXIMUMLIKELIHOODSTAT_PERIODDEFICIT = org.jpmml.model.ReflectionUtil.getField(MaximumLikelihoodStat.class, "periodDeficit");
    Field NONSEASONALCOMPONENT_P = org.jpmml.model.ReflectionUtil.getField(NonseasonalComponent.class, "p");
    Field NONSEASONALCOMPONENT_D = org.jpmml.model.ReflectionUtil.getField(NonseasonalComponent.class, "d");
    Field NONSEASONALCOMPONENT_Q = org.jpmml.model.ReflectionUtil.getField(NonseasonalComponent.class, "q");
    Field NONSEASONALFACTOR_DIFFERENCE = org.jpmml.model.ReflectionUtil.getField(NonseasonalFactor.class, "difference");
    Field NONSEASONALFACTOR_MAXIMUMORDER = org.jpmml.model.ReflectionUtil.getField(NonseasonalFactor.class, "maximumOrder");
    Field OUTLIEREFFECT_TYPE = org.jpmml.model.ReflectionUtil.getField(OutlierEffect.class, "type");
    Field OUTLIEREFFECT_STARTTIME = org.jpmml.model.ReflectionUtil.getField(OutlierEffect.class, "startTime");
    Field OUTLIEREFFECT_MAGNITUDE = org.jpmml.model.ReflectionUtil.getField(OutlierEffect.class, "magnitude");
    Field OUTLIEREFFECT_DAMPINGCOEFFICIENT = org.jpmml.model.ReflectionUtil.getField(OutlierEffect.class, "dampingCoefficient");
    Field PSIVECTOR_TARGETFIELD = org.jpmml.model.ReflectionUtil.getField(PsiVector.class, "targetField");
    Field PSIVECTOR_VARIANCE = org.jpmml.model.ReflectionUtil.getField(PsiVector.class, "variance");
    Field SEASONALCOMPONENT_P = org.jpmml.model.ReflectionUtil.getField(SeasonalComponent.class, "p");
    Field SEASONALCOMPONENT_D = org.jpmml.model.ReflectionUtil.getField(SeasonalComponent.class, "d");
    Field SEASONALCOMPONENT_Q = org.jpmml.model.ReflectionUtil.getField(SeasonalComponent.class, "q");
    Field SEASONALCOMPONENT_PERIOD = org.jpmml.model.ReflectionUtil.getField(SeasonalComponent.class, "period");
    Field SEASONALFACTOR_DIFFERENCE = org.jpmml.model.ReflectionUtil.getField(SeasonalFactor.class, "difference");
    Field SEASONALFACTOR_MAXIMUMORDER = org.jpmml.model.ReflectionUtil.getField(SeasonalFactor.class, "maximumOrder");
    Field SEASONALITYEXPOSMOOTH_TYPE = org.jpmml.model.ReflectionUtil.getField(SeasonalityExpoSmooth.class, "type");
    Field SEASONALITYEXPOSMOOTH_PERIOD = org.jpmml.model.ReflectionUtil.getField(SeasonalityExpoSmooth.class, "period");
    Field SEASONALITYEXPOSMOOTH_UNIT = org.jpmml.model.ReflectionUtil.getField(SeasonalityExpoSmooth.class, "unit");
    Field SEASONALITYEXPOSMOOTH_PHASE = org.jpmml.model.ReflectionUtil.getField(SeasonalityExpoSmooth.class, "phase");
    Field SEASONALITYEXPOSMOOTH_DELTA = org.jpmml.model.ReflectionUtil.getField(SeasonalityExpoSmooth.class, "delta");
    Field STATESPACEMODEL_VARIANCE = org.jpmml.model.ReflectionUtil.getField(StateSpaceModel.class, "variance");
    Field STATESPACEMODEL_PERIOD = org.jpmml.model.ReflectionUtil.getField(StateSpaceModel.class, "period");
    Field STATESPACEMODEL_INTERCEPT = org.jpmml.model.ReflectionUtil.getField(StateSpaceModel.class, "intercept");
    Field THETA_I = org.jpmml.model.ReflectionUtil.getField(Theta.class, "i");
    Field THETA_J = org.jpmml.model.ReflectionUtil.getField(Theta.class, "j");
    Field THETA_THETA = org.jpmml.model.ReflectionUtil.getField(Theta.class, "theta");
    Field TIMEANCHOR_TYPE = org.jpmml.model.ReflectionUtil.getField(TimeAnchor.class, "type");
    Field TIMEANCHOR_OFFSET = org.jpmml.model.ReflectionUtil.getField(TimeAnchor.class, "offset");
    Field TIMEANCHOR_STEPSIZE = org.jpmml.model.ReflectionUtil.getField(TimeAnchor.class, "stepsize");
    Field TIMEANCHOR_DISPLAYNAME = org.jpmml.model.ReflectionUtil.getField(TimeAnchor.class, "displayName");
    Field TIMECYCLE_LENGTH = org.jpmml.model.ReflectionUtil.getField(TimeCycle.class, "length");
    Field TIMECYCLE_TYPE = org.jpmml.model.ReflectionUtil.getField(TimeCycle.class, "type");
    Field TIMECYCLE_DISPLAYNAME = org.jpmml.model.ReflectionUtil.getField(TimeCycle.class, "displayName");
    Field TIMEEXCEPTION_TYPE = org.jpmml.model.ReflectionUtil.getField(TimeException.class, "type");
    Field TIMEEXCEPTION_COUNT = org.jpmml.model.ReflectionUtil.getField(TimeException.class, "count");
    Field TIMESERIES_USAGE = org.jpmml.model.ReflectionUtil.getField(TimeSeries.class, "usage");
    Field TIMESERIES_STARTTIME = org.jpmml.model.ReflectionUtil.getField(TimeSeries.class, "startTime");
    Field TIMESERIES_ENDTIME = org.jpmml.model.ReflectionUtil.getField(TimeSeries.class, "endTime");
    Field TIMESERIES_INTERPOLATIONMETHOD = org.jpmml.model.ReflectionUtil.getField(TimeSeries.class, "interpolationMethod");
    Field TIMESERIES_FIELD = org.jpmml.model.ReflectionUtil.getField(TimeSeries.class, "field");
    Field TIMESERIESMODEL_MODELNAME = org.jpmml.model.ReflectionUtil.getField(TimeSeriesModel.class, "modelName");
    Field TIMESERIESMODEL_MININGFUNCTION = org.jpmml.model.ReflectionUtil.getField(TimeSeriesModel.class, "miningFunction");
    Field TIMESERIESMODEL_ALGORITHMNAME = org.jpmml.model.ReflectionUtil.getField(TimeSeriesModel.class, "algorithmName");
    Field TIMESERIESMODEL_BESTFIT = org.jpmml.model.ReflectionUtil.getField(TimeSeriesModel.class, "bestFit");
    Field TIMESERIESMODEL_SCORABLE = org.jpmml.model.ReflectionUtil.getField(TimeSeriesModel.class, "scorable");
    Field TIMESERIESMODEL_MATHCONTEXT = org.jpmml.model.ReflectionUtil.getField(TimeSeriesModel.class, "mathContext");
    Field TIMEVALUE_INDEX = org.jpmml.model.ReflectionUtil.getField(TimeValue.class, "index");
    Field TIMEVALUE_TIME = org.jpmml.model.ReflectionUtil.getField(TimeValue.class, "time");
    Field TIMEVALUE_VALUE = org.jpmml.model.ReflectionUtil.getField(TimeValue.class, "value");
    Field TIMEVALUE_STANDARDERROR = org.jpmml.model.ReflectionUtil.getField(TimeValue.class, "standardError");
    Field TRENDEXPOSMOOTH_TREND = org.jpmml.model.ReflectionUtil.getField(TrendExpoSmooth.class, "trend");
    Field TRENDEXPOSMOOTH_GAMMA = org.jpmml.model.ReflectionUtil.getField(TrendExpoSmooth.class, "gamma");
    Field TRENDEXPOSMOOTH_PHI = org.jpmml.model.ReflectionUtil.getField(TrendExpoSmooth.class, "phi");
    Field TRENDEXPOSMOOTH_SMOOTHEDVALUE = org.jpmml.model.ReflectionUtil.getField(TrendExpoSmooth.class, "smoothedValue");

}
